Learn R Programming

FAiR (version 0.4-13)

restrictions-class: Class "restrictions"

Description

It is not necessary to understand this help page if one merely wants to estimate a factor analysis model. This help page is intended for those who want to modify or extend FAiR or otherwise want some idea of how FAiR works behind the scenes.

This class contains information in its slots about what restrictions are placed on a factor analysis model, which defines the model to be estimated.

Arguments

Objects from the Class

Objects can be created by calls of the form new("restrictions", ...). However, it is not recommended to do so in normal usage because make_restrictions provides the constructor for users.

Details

These classes are fundamental in FAiR and fulfill two important roles. First, they serve as a vessel that contains the parameter matrices and other necessary information to estimate different factor analysis models via Factanal. During the genetic optimization proccess, the restrictions2model method repeatedly calls make_parameter-methods to fill the empty x slots of the matrices within the "restrictions" object that inherit from parameter-class. Eventually, the optimal parameters satisfying the specified constraints are found by the genetic algorithm and the create_FAobject creates an object that inherits from class FA-class on the basis of this filled "restrictions" object.

The second purpose of a "restrictions" object is to remind the user of exactly what restrictions were imposed during the estimation process, which is why a tailored show method is essential.

Here is a table of the class hierarchy: lll{ Class Parent Class Corresponding Model "restrictions" none none (virtual class) "restrictions.independent" "retrictions" zero factor null model "restrictions.factanal" "restrictions" EFA via factanal algorithm "restrictions.orthonormal" "restrictions" EFA via a different algorithm "restrictions.1storder" "restrictions" Models with correlated factors "restrictions.1storder.EFA" "restrictions.1storder" EFA after factor transformation "restrictions.general" "restrictions.1storder" SEFA and CFA "restrictions.2ndorder" "restrictions.general" SEFA and CFA }

See Also

make_restrictions

Examples

Run this code
showClass("restrictions")
showClass("restrictions.independent")
showClass("restrictions.orthonormal")
showClass("restrictions.1storder")
showClass("restrictions.1storder.EFA")
showClass("restrictions.general")
showClass("restrictions.2ndorder")

Run the code above in your browser using DataLab