restrictions2draws directly; it is more common to use
FA2draws, which calls restrictions2draws internally.FA2draws(object, nsim = 1001, seed = NULL,
covariances = FALSE, standardized = TRUE, ...)FA-classNULL will not change the random
generator stateTRUE, returns the simulations
nsim.FA2draws is not a S4 generic function, but it primarily exists to call
the S4 generic function, restrictions2draws. Methods are currently only defined
for objects of class "manifest.basic", which are inherited by objects of class
"manifest.data" and "manifest.data.mcd". There are methods
for each flavor of restrictions-class, except for
"restrictions.factanal".
There are also at least four arguments that are not part of the
signature of restrictions2draws. The first is vcov, which is the
variance-covariance matrix for the free parameters and is simply extracted from
the slot of the object of FA-class. The second through fourth arguments
are nsim, covariances, and standardized as documented in the
arguments section. For the restrictions2draws method defined for class "restrictions.orthonormal",
there are two additional arguments. The first is Tmat, which can be
NULL but can also be an optimal transformation matrix (found by
Rotate). The second is criteria, which is a list of
criteria utilized when finding the optimal transformation matrix. If both
of these arguments are specified, the method will produce draws of the
transformed parameters, after generating them from a multivariate normal
distribution. They are extracted from the object of FA-class as
necessary.
nsim acceptable simulations have been
obtained, they are returned in a list of arrays for further analysis.confint,FA-method, simulate, and
summary.FA-class